<?php
/**
* @package RSMediaGallery! Advanced Slideshow Module
* @copyright (C) 2011 - 2021 www.rsjoomla.com
* @license GPL, http://www.gnu.org/licenses/gpl-3.0.html
*/
defined('_JEXEC') or die('Restricted access');

if (file_exists(JPATH_ADMINISTRATOR.'/components/com_rsmediagallery/helpers/helper.php') && file_exists(JPATH_SITE.'/components/com_rsmediagallery/helpers/route.php')) {
	
	require_once JPATH_SITE.'/components/com_rsmediagallery/helpers/route.php';
	require_once JPATH_ADMINISTRATOR.'/components/com_rsmediagallery/helpers/helper.php';

	$componentParams    = JComponentHelper::getParams('com_rsmediagallery');
	$document           = JFactory::getDocument();
    $min                = JDEBUG ? '' : '.min';

	// CSS
	JHtml::_('stylesheet', 'mod_rsmediagallery_adv_slideshow/style.css', array('relative' => true, 'version' => 'auto'));
	JHtml::_('stylesheet', 'mod_rsmediagallery_adv_slideshow/'.$componentParams->get('contrast', 'light').'.css', array('relative' => true, 'version' => 'auto'));

	// Javascript
	JHtml::_('jquery.framework');
	$document->addScriptDeclaration('jQuery.noConflict();');
	JHtml::_('script', 'mod_rsmediagallery_adv_slideshow/jquery.easing.1.3'.$min.'.js', array('relative' => true, 'version' => 'auto'));
	JHtml::_('script', 'mod_rsmediagallery_adv_slideshow/jquery.skitter'.$min.'.js', array('relative' => true, 'version' => 'auto'));

	$theme				= $params->get('slideshow_type', 'square');
	$effect				= $params->get('effect', 'cubeRandom');
	$auto_play			= (int) $params->get('auto_play', 1);
	$stop_over			= (int) $params->get('stop_over', 1);
	$interval			= (int) $params->get('interval', 2500);
	$show_progressbar	= (int) $params->get('show_progressbar', 1);
	$show_prev_next		= (int) $params->get('show_prev_next', 1);
	$show_controls		= (int) $params->get('show_controls', 1);
	$controls_position	= $params->get('controls_position', 'center');
	$navigation_type	= $params->get('navigation_type', 'dots_thumbs');
	$navigation_align	= $params->get('navigation_align', 'center');
	$show_label			= (int) $params->get('show_label', 1);
	$label_animation	= $params->get('label_animation', 'slideUp');
	$use_original		= (int) $params->get('use_original', 0);
	$open_in_new_page	= (int) $params->get('open_in_new_page', 1);
	$moduleclass_sfx	= $params->get('moduleclass_sfx','');

	$use_url			= $params->get('use_url', 1);
	$tags 				= !empty($params->get('tags')) ? $params->get('tags') : RSMediaGalleryHelper::getAllTags();
	$order 				= $params->get('ordering', 'ordering');
	$direction			= $params->get('direction', 'ASC');
	$limit 				= $params->get('limit', '5');

	$gallery_params		= RSMediaGalleryHelper::parseParams($params);

	switch ($navigation_type) {
		case 'none':
			$navigation = "\n\t\t\t\t\tdots\t\t\t\t: false,\n\t\t\t\t\tnumbers\t\t\t\t: false,";
		break;
		
		case 'dots':
			$navigation = "\n\t\t\t\t\tdots\t\t\t\t: true,";
		break;
		
		case 'dots_thumbs':
			$navigation = "\n\t\t\t\t\tdots\t\t\t\t: true,\n\t\t\t\t\tpreview\t\t\t\t: true,";
		break;
		
		case 'thumbs':
			$navigation = "\n\t\t\t\t\tthumbs\t\t\t\t: true,";
		break;
		
		case 'numbers':
			$navigation = "\n\t\t\t\t\tdots\t\t\t\t: false,\n\t\t\t\t\tnumbers\t\t\t\t: true,";
		break;
		
		default:
			$navigation = '';
		break;
	}

	$items = array();

	if ($tags) {
		$items = RSMediaGalleryHelper::getItems($tags, $order, $direction, 0, $limit);
		if (empty($items)) { 
			JFactory::getApplication()->enqueueMessage(JText::sprintf('COM_RSMEDIAGALLERY_PARAM_TAGS_NO_RESULTS', $tags), 'error');
		}
	} else {
		JFactory::getApplication()->enqueueMessage(JText::sprintf('COM_RSMEDIAGALLERY_PARAM_TAGS_NO_RESULTS', $tags), 'error');
	}

	// calculating slider width or height
	if ($items) {
		foreach ($items as $i => $item) {
			$item->from = 'mod_rsmediagallery_adv_slideshow';
			$items[$i] = RSMediaGalleryHelper::parseItem($item, $gallery_params);
			
			if (!$use_url || empty($items[$i]->url)) {
				$items[$i]->url = 'javascript:void(0);';
			}
		}
	}

	$item_height    = 0;
	$max_height     = 0;
	$max_width      = 0;

	if ($use_original) {
		if ($items) {
			foreach ($items as $item) {
				if ($item->params = $item->params ? unserialize($item->params) : array()) {
					$max_width  = max($max_width, $item->params['info'][0]);
					$max_height = max($max_height, $item->params['info'][1]);
				}
			}
		}
	} else {
		if ($items) {
			foreach ($items as $item) {
				if ($item->params = $item->params ? unserialize($item->params) : array()) {
					if ($params->get('thumb_height') == 0) {
						$max_width      = $params->get('thumb_width');
						$max_height     = max($max_height, $item->thumb_height);
                        $item_height    = $item->thumb_height;
					} else {
						$max_width      = $item->thumb_width;
						$max_height     = max($max_height, $params->get('thumb_height'));
                        $item_height    = $params->get('thumb_height');
					}
				}
			}
		}
	}

	if ($items) {
		$document->addStyleDeclaration('
            #rsmg_adv_mod_slider'.$module->id.' rsmg_adv_mod_container {
                max-height: '.$max_height.'px;
                max-width: '.$max_width.'px;
                margin: 0 auto;
            }
		');

		$document->addScriptDeclaration("
			jQuery(document).ready(function(){
				jQuery('#rsmg_adv_mod_slider$module->id').skitter({
					id                  : ".$module->id.",
					theme               : '".RSMediaGalleryHelper::escape($theme)."',
					animation           : '".RSMediaGalleryHelper::escape($effect)."',
					auto_play           : ".($auto_play ? 'true' : 'false').",
					stop_over           : ".($stop_over ? 'true' : 'false').",
					interval            : ".$interval.",
					progressbar         : ".($show_progressbar ? 'true' : 'false').",
					navigation          : ".($show_prev_next ? 'true' : 'false').",
					controls            : ".($show_controls ? 'true' : 'false').",
					controls_position   : '".RSMediaGalleryHelper::escape($controls_position)."', ".$navigation."
					numbers_align       : '".RSMediaGalleryHelper::escape($navigation_align)."',
					label               : ".($show_label ? 'true' : 'false').",
					labelAnimation      : '".RSMediaGalleryHelper::escape($label_animation)."',
				});
			});
		");

		// Display template
		require JModuleHelper::getLayoutPath('mod_rsmediagallery_adv_slideshow');
	}
} else {
	JFactory::getApplication()->enqueueMessage(JText::_('MOD_RSMEDIAGALLERY_ADV_SLIDESHOW_COMPONENT_NOT_INSTALLED_OR_UPDATED'), 'error');
}
